@@ -280,7 +280,7 @@ class LowRankRegressor(BaseEstimator, RegressorMixin):
             D = (K_tv_X.T@U).T
             E = (V.T)@(self.K_Y_@V)
 
-            M = (val_dim**(-1))*(K_v_Y -(C@D + (D.T)@(C.T)) + (val_dim**(-1))*((D.T)@E@(D)))
+            M = (val_dim**(-1))*(K_v_Y -(C@D + (D.T)@(C.T)) + ((D.T)@E@(D)))
             sigma_1_sq = np.max(np.linalg.eigvalsh(M))
             return np.sqrt(sigma_1_sq)
         else:
